@@ -2,12 +2,12 @@
 #define __RIFF_hpp__ 1
 
 // =================================================================================================
-// ADOBE SYSTEMS INCORPORATED
-// Copyright 2009 Adobe Systems Incorporated
+// Copyright Adobe
+// Copyright 2009 Adobe
 // All Rights Reserved
 //
 // NOTICE: Adobe permits you to use, modify, and distribute this file in accordance with the terms
-// of the Adobe license agreement accompanying it.
+// of the Adobe license agreement accompanying it. 
 // =================================================================================================
 
 #include "public/include/XMP_Environment.h"	// ! XMP_Environment.h must be the first included header.
@@ -160,7 +160,7 @@ namespace RIFF {
 		//{ kPropChunkISRC, to be decided,	"" ,		prop_SIMPLE },
 		//{ kPropChunkITCH, to be decided,	"" ,		prop_SIMPLE },
 
-		{ 0, 0, 0 }	// sentinel
+		{ 0, 0, 0, prop_SIMPLE }	// sentinel
 	};
 
 	static Mapping listTdatProps[] = {
@@ -169,17 +169,17 @@ namespace RIFF {
 		{ kPropChunk_tc_A, kXMP_NS_DM,	"altTimecode"	, prop_TIMEVALUE },   // special: must end up in dm:timeValue child
 		{ kPropChunk_rn_O, kXMP_NS_DM,	"tapeName"		, prop_SIMPLE  },
 		{ kPropChunk_rn_A, kXMP_NS_DM,	"altTapeName"	, prop_SIMPLE  },
-		{ 0, 0, 0 }	// sentinel
+		{ 0, 0, 0, prop_SIMPLE }	// sentinel
 	};
 
 	// =================================================================================================
 	// ImportCr8rItems
 	// ===============
-#if SUNOS_SPARC || SUNOS_X86
+#if SUNOS_SPARC || SUNOS_X86 || XMP_ANDROID_ARM
 	#pragma pack ( 1 )
 #else
 	#pragma pack ( push, 1 )
-#endif //#if SUNOS_SPARC || SUNOS_X86
+#endif //#if SUNOS_SPARC || SUNOS_X86 || XMP_ANDROID_ARM
 	struct PrmLBoxContent {
 		XMP_Uns32 magic;
 		XMP_Uns32 size;
@@ -204,7 +204,7 @@ namespace RIFF {
 		char appOptions[16];
 		char appName[32];
 	};
-#if SUNOS_SPARC || SUNOS_X86
+#if SUNOS_SPARC || SUNOS_X86 || XMP_AndroidBuild
 	#pragma pack (  )
 #else
 	#pragma pack ( pop )
